@@ -1,7 +1,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2005-2017. All Rights Reserved.
+%% Copyright Ericsson AB 2005-2021. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -27,7 +27,8 @@
 	 convert_month/1, 
 	 is_hostname/1,
 	 timestamp/0, timeout/2,
-	 html_encode/1
+	 html_encode/1,
+	 maybe_add_brackets/2
 	]).
 
 
@@ -122,12 +123,12 @@ convert_netscapecookie_date([_D,_A,_Y, $ ,
     {{Year,Month,Day},{Hour,Min,Sec}};
 
 %% Sloppy...
-convert_netscapecookie_date([_D,_A,_Y, $,, _SP,
-                             D1,D2,_DA,
-                             M,O,N,_DA,
-                             Y1,Y2,Y3,Y4,_SP,
-                             H1,H2,_Col,
-                             M1,M2,_Col,
+convert_netscapecookie_date([_D,_A,_Y, $,, SP,
+                             D1,D2,DA,
+                             M,O,N,DA,
+                             Y1,Y2,Y3,Y4,SP,
+                             H1,H2,Col,
+                             M1,M2,Col,
                              S1,S2|_Rest]) ->
     Year=list_to_integer([Y1,Y2,Y3,Y4]),
     Day=list_to_integer([D1,D2]),
@@ -137,12 +138,12 @@ convert_netscapecookie_date([_D,_A,_Y, $,, _SP,
     Sec=list_to_integer([S1,S2]),
     {{Year,Month,Day},{Hour,Min,Sec}};
 
-convert_netscapecookie_date([_D,_A,_Y, _SP,
-                             D1,D2,_DA,
-                             M,O,N,_DA,
-                             Y1,Y2,Y3,Y4,_SP,
-                             H1,H2,_Col,
-                             M1,M2,_Col,
+convert_netscapecookie_date([_D,_A,_Y, SP,
+                             D1,D2,DA,
+                             M,O,N,DA,
+                             Y1,Y2,Y3,Y4,SP,
+                             H1,H2,Col,
+                             M1,M2,Col,
                              S1,S2|_Rest]) ->
     Year=list_to_integer([Y1,Y2,Y3,Y4]),
     Day=list_to_integer([D1,D2]),
@@ -194,6 +195,24 @@ html_encode(Chars) ->
     lists:append([char_to_html_entity(Char, Reserved) || Char <- Chars]).
 
 
+maybe_add_brackets(Addr, false) ->
+    Addr;
+maybe_add_brackets(Addr, true) when is_list(Addr) ->
+    case is_ipv6_address(Addr) of
+        true ->
+            [$[|Addr] ++ "]";
+        false ->
+            Addr
+    end;
+maybe_add_brackets(Addr, true) when is_binary(Addr) ->
+    case is_ipv6_address(Addr) of
+        true ->
+            <<$[,Addr/binary,$]>>;
+        false ->
+            Addr
+    end.
+
+
 %%%========================================================================
 %%% Internal functions
 %%%========================================================================
@@ -205,3 +224,14 @@ char_to_html_entity(Char, Reserved) ->
 	false ->
 	    [Char]
     end.
+
+is_ipv6_address(Addr) when is_binary(Addr) ->
+    B = binary_to_list(Addr),
+    is_ipv6_address(B);
+is_ipv6_address(Addr) when is_list(Addr) ->
+    case inet:parse_ipv6strict_address(Addr) of
+        {ok, _ } ->
+            true;
+        {error, _} ->
+            false
+    end.
